# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class Stream(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'can_read': 'bool',
        'can_seek': 'bool',
        'can_timeout': 'bool',
        'can_write': 'bool',
        'length': 'int',
        'position': 'int',
        'read_timeout': 'int',
        'write_timeout': 'int'
    }

    attribute_map = {
        'can_read': 'canRead',
        'can_seek': 'canSeek',
        'can_timeout': 'canTimeout',
        'can_write': 'canWrite',
        'length': 'length',
        'position': 'position',
        'read_timeout': 'readTimeout',
        'write_timeout': 'writeTimeout'
    }

    def __init__(self, can_read=None, can_seek=None, can_timeout=None, can_write=None, length=None, position=None, read_timeout=None, write_timeout=None, local_vars_configuration=None):  # noqa: E501
        """Stream - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._can_read = None
        self._can_seek = None
        self._can_timeout = None
        self._can_write = None
        self._length = None
        self._position = None
        self._read_timeout = None
        self._write_timeout = None
        self.discriminator = None

        if can_read is not None:
            self.can_read = can_read
        if can_seek is not None:
            self.can_seek = can_seek
        if can_timeout is not None:
            self.can_timeout = can_timeout
        if can_write is not None:
            self.can_write = can_write
        if length is not None:
            self.length = length
        if position is not None:
            self.position = position
        if read_timeout is not None:
            self.read_timeout = read_timeout
        if write_timeout is not None:
            self.write_timeout = write_timeout

    @property
    def can_read(self):
        """Gets the can_read of this Stream.  # noqa: E501


        :return: The can_read of this Stream.  # noqa: E501
        :rtype: bool
        """
        return self._can_read

    @can_read.setter
    def can_read(self, can_read):
        """Sets the can_read of this Stream.


        :param can_read: The can_read of this Stream.  # noqa: E501
        :type: bool
        """

        self._can_read = can_read

    @property
    def can_seek(self):
        """Gets the can_seek of this Stream.  # noqa: E501


        :return: The can_seek of this Stream.  # noqa: E501
        :rtype: bool
        """
        return self._can_seek

    @can_seek.setter
    def can_seek(self, can_seek):
        """Sets the can_seek of this Stream.


        :param can_seek: The can_seek of this Stream.  # noqa: E501
        :type: bool
        """

        self._can_seek = can_seek

    @property
    def can_timeout(self):
        """Gets the can_timeout of this Stream.  # noqa: E501


        :return: The can_timeout of this Stream.  # noqa: E501
        :rtype: bool
        """
        return self._can_timeout

    @can_timeout.setter
    def can_timeout(self, can_timeout):
        """Sets the can_timeout of this Stream.


        :param can_timeout: The can_timeout of this Stream.  # noqa: E501
        :type: bool
        """

        self._can_timeout = can_timeout

    @property
    def can_write(self):
        """Gets the can_write of this Stream.  # noqa: E501


        :return: The can_write of this Stream.  # noqa: E501
        :rtype: bool
        """
        return self._can_write

    @can_write.setter
    def can_write(self, can_write):
        """Sets the can_write of this Stream.


        :param can_write: The can_write of this Stream.  # noqa: E501
        :type: bool
        """

        self._can_write = can_write

    @property
    def length(self):
        """Gets the length of this Stream.  # noqa: E501


        :return: The length of this Stream.  # noqa: E501
        :rtype: int
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this Stream.


        :param length: The length of this Stream.  # noqa: E501
        :type: int
        """

        self._length = length

    @property
    def position(self):
        """Gets the position of this Stream.  # noqa: E501


        :return: The position of this Stream.  # noqa: E501
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this Stream.


        :param position: The position of this Stream.  # noqa: E501
        :type: int
        """

        self._position = position

    @property
    def read_timeout(self):
        """Gets the read_timeout of this Stream.  # noqa: E501


        :return: The read_timeout of this Stream.  # noqa: E501
        :rtype: int
        """
        return self._read_timeout

    @read_timeout.setter
    def read_timeout(self, read_timeout):
        """Sets the read_timeout of this Stream.


        :param read_timeout: The read_timeout of this Stream.  # noqa: E501
        :type: int
        """

        self._read_timeout = read_timeout

    @property
    def write_timeout(self):
        """Gets the write_timeout of this Stream.  # noqa: E501


        :return: The write_timeout of this Stream.  # noqa: E501
        :rtype: int
        """
        return self._write_timeout

    @write_timeout.setter
    def write_timeout(self, write_timeout):
        """Sets the write_timeout of this Stream.


        :param write_timeout: The write_timeout of this Stream.  # noqa: E501
        :type: int
        """

        self._write_timeout = write_timeout

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Stream):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Stream):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_identity_service.api_client import ApiClient
from dhicn_identity_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class TenantManagerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_app_tenant_manager_init_super_admin_post(self, **kwargs):  # noqa: E501
        """初始化超级管理员 Initialize super administrator  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_init_super_admin_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_init_super_admin_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_tenant_manager_init_super_admin_post_with_http_info(self, **kwargs):  # noqa: E501
        """初始化超级管理员 Initialize super administrator  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_init_super_admin_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_init_super_admin_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/initSuperAdmin', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_license_datas_get(self, **kwargs):  # noqa: E501
        """生成License数据 Generate licence data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_license_datas_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int tenant_number: 租户个数 tenant number
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: LicenseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_license_datas_get_with_http_info(**kwargs)  # noqa: E501

    def api_app_tenant_manager_license_datas_get_with_http_info(self, **kwargs):  # noqa: E501
        """生成License数据 Generate licence data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_license_datas_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int tenant_number: 租户个数 tenant number
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(LicenseData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_number'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_license_datas_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_number' in local_var_params and local_var_params['tenant_number'] is not None:  # noqa: E501
            query_params.append(('TenantNumber', local_var_params['tenant_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/licenseDatas', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LicenseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_refresh_tenant_get(self, **kwargs):  # noqa: E501
        """刷新租户缓存 Refresh tenant cache  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_refresh_tenant_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_refresh_tenant_get_with_http_info(**kwargs)  # noqa: E501

    def api_app_tenant_manager_refresh_tenant_get_with_http_info(self, **kwargs):  # noqa: E501
        """刷新租户缓存 Refresh tenant cache  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_refresh_tenant_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_refresh_tenant_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/refreshTenant', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_systems_get(self, **kwargs):  # noqa: E501
        """获取所有的系统 Get all the systems  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_systems_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GuidStringKeyValue]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_systems_get_with_http_info(**kwargs)  # noqa: E501

    def api_app_tenant_manager_systems_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有的系统 Get all the systems  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_systems_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GuidStringKeyValue], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_systems_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/systems', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GuidStringKeyValue]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_systems_with_type_get(self, **kwargs):  # noqa: E501
        """获取所有的系统详细信息 Get all the systems detailed information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_systems_with_type_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GetSystemsOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_systems_with_type_get_with_http_info(**kwargs)  # noqa: E501

    def api_app_tenant_manager_systems_with_type_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有的系统详细信息 Get all the systems detailed information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_systems_with_type_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GetSystemsOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_systems_with_type_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/systemsWithType', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GetSystemsOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_tenant_delete(self, id, **kwargs):  # noqa: E501
        """删除租户 Delete tenant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenant_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_tenant_delete_with_http_info(id, **kwargs)  # noqa: E501

    def api_app_tenant_manager_tenant_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """删除租户 Delete tenant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenant_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_tenant_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `api_app_tenant_manager_tenant_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in local_var_params and local_var_params['id'] is not None:  # noqa: E501
            query_params.append(('Id', local_var_params['id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/tenant', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_tenant_personalizedinfo_tenant_id_get(self, tenant_id, **kwargs):  # noqa: E501
        """获取租户个性化信息 Get tenant personalized information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenant_personalizedinfo_tenant_id_get(tenant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id: 租户ID tenant id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TenantPersonalizedInfoDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_tenant_personalizedinfo_tenant_id_get_with_http_info(tenant_id, **kwargs)  # noqa: E501

    def api_app_tenant_manager_tenant_personalizedinfo_tenant_id_get_with_http_info(self, tenant_id, **kwargs):  # noqa: E501
        """获取租户个性化信息 Get tenant personalized information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenant_personalizedinfo_tenant_id_get_with_http_info(tenant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id: 租户ID tenant id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TenantPersonalizedInfoDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_tenant_personalizedinfo_tenant_id_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tenant_id' is set
        if self.api_client.client_side_validation and ('tenant_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['tenant_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `tenant_id` when calling `api_app_tenant_manager_tenant_personalizedinfo_tenant_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tenant_id' in local_var_params:
            path_params['tenantId'] = local_var_params['tenant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/tenantPersonalizedinfo/{tenantId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TenantPersonalizedInfoDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_tenant_post(self, **kwargs):  # noqa: E501
        """添加租户 Add tenant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenant_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddTenantInput add_tenant_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_tenant_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_tenant_manager_tenant_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加租户 Add tenant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenant_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddTenantInput add_tenant_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_tenant_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_tenant_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_tenant_input' in local_var_params:
            body_params = local_var_params['add_tenant_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/tenant', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_tenant_put(self, **kwargs):  # noqa: E501
        """修改租户信息 Update tenant information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenant_put(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateTenantInput update_tenant_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_tenant_put_with_http_info(**kwargs)  # noqa: E501

    def api_app_tenant_manager_tenant_put_with_http_info(self, **kwargs):  # noqa: E501
        """修改租户信息 Update tenant information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenant_put_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateTenantInput update_tenant_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_tenant_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_tenant_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_tenant_input' in local_var_params:
            body_params = local_var_params['update_tenant_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/tenant', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_tenants_by_system_id_system_id_get(self, system_id, **kwargs):  # noqa: E501
        """获取系统下的租户 Get tenants by systerm id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenants_by_system_id_system_id_get(system_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str system_id: 系统ID system id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GetTenantsBySysOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_tenants_by_system_id_system_id_get_with_http_info(system_id, **kwargs)  # noqa: E501

    def api_app_tenant_manager_tenants_by_system_id_system_id_get_with_http_info(self, system_id, **kwargs):  # noqa: E501
        """获取系统下的租户 Get tenants by systerm id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenants_by_system_id_system_id_get_with_http_info(system_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str system_id: 系统ID system id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GetTenantsBySysOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'system_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_tenants_by_system_id_system_id_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'system_id' is set
        if self.api_client.client_side_validation and ('system_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['system_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `system_id` when calling `api_app_tenant_manager_tenants_by_system_id_system_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'system_id' in local_var_params:
            path_params['systemId'] = local_var_params['system_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/tenantsBySystemId/{systemId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GetTenantsBySysOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_tenant_manager_tenants_get(self, **kwargs):  # noqa: E501
        """查询租户列表 Query tenant list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenants_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: 租户名称 tenant name
        :param str system_id: 系统ID system id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GetTenantsOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_tenant_manager_tenants_get_with_http_info(**kwargs)  # noqa: E501

    def api_app_tenant_manager_tenants_get_with_http_info(self, **kwargs):  # noqa: E501
        """查询租户列表 Query tenant list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_tenant_manager_tenants_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: 租户名称 tenant name
        :param str system_id: 系统ID system id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GetTenantsOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name',
            'system_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_tenant_manager_tenants_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('Name', local_var_params['name']))  # noqa: E501
        if 'system_id' in local_var_params and local_var_params['system_id'] is not None:  # noqa: E501
            query_params.append(('SystemId', local_var_params['system_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/tenantManager/tenants', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GetTenantsOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class UserInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_name': 'str',
        'sur_name': 'str',
        'phone_number': 'str',
        'email': 'str',
        'role_infos': 'list[RoleInfo]'
    }

    attribute_map = {
        'id': 'id',
        'user_name': 'userName',
        'sur_name': 'surName',
        'phone_number': 'phoneNumber',
        'email': 'email',
        'role_infos': 'roleInfos'
    }

    def __init__(self, id=None, user_name=None, sur_name=None, phone_number=None, email=None, role_infos=None, local_vars_configuration=None):  # noqa: E501
        """UserInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_name = None
        self._sur_name = None
        self._phone_number = None
        self._email = None
        self._role_infos = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.user_name = user_name
        self.sur_name = sur_name
        self.phone_number = phone_number
        self.email = email
        self.role_infos = role_infos

    @property
    def id(self):
        """Gets the id of this UserInformation.  # noqa: E501


        :return: The id of this UserInformation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserInformation.


        :param id: The id of this UserInformation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_name(self):
        """Gets the user_name of this UserInformation.  # noqa: E501


        :return: The user_name of this UserInformation.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this UserInformation.


        :param user_name: The user_name of this UserInformation.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def sur_name(self):
        """Gets the sur_name of this UserInformation.  # noqa: E501


        :return: The sur_name of this UserInformation.  # noqa: E501
        :rtype: str
        """
        return self._sur_name

    @sur_name.setter
    def sur_name(self, sur_name):
        """Sets the sur_name of this UserInformation.


        :param sur_name: The sur_name of this UserInformation.  # noqa: E501
        :type: str
        """

        self._sur_name = sur_name

    @property
    def phone_number(self):
        """Gets the phone_number of this UserInformation.  # noqa: E501


        :return: The phone_number of this UserInformation.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this UserInformation.


        :param phone_number: The phone_number of this UserInformation.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def email(self):
        """Gets the email of this UserInformation.  # noqa: E501


        :return: The email of this UserInformation.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserInformation.


        :param email: The email of this UserInformation.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def role_infos(self):
        """Gets the role_infos of this UserInformation.  # noqa: E501


        :return: The role_infos of this UserInformation.  # noqa: E501
        :rtype: list[RoleInfo]
        """
        return self._role_infos

    @role_infos.setter
    def role_infos(self, role_infos):
        """Sets the role_infos of this UserInformation.


        :param role_infos: The role_infos of this UserInformation.  # noqa: E501
        :type: list[RoleInfo]
        """

        self._role_infos = role_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-configuration-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_configuration_service.configuration import Configuration


class QueryTemplateListOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'file_name': 'str',
        'enable': 'bool',
        'remark': 'str',
        'version': 'int',
        'library_type': 'str',
        'business_type': 'str',
        'model_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'file_name': 'fileName',
        'enable': 'enable',
        'remark': 'remark',
        'version': 'version',
        'library_type': 'libraryType',
        'business_type': 'businessType',
        'model_type': 'modelType'
    }

    def __init__(self, id=None, file_name=None, enable=None, remark=None, version=None, library_type=None, business_type=None, model_type=None, local_vars_configuration=None):  # noqa: E501
        """QueryTemplateListOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._file_name = None
        self._enable = None
        self._remark = None
        self._version = None
        self._library_type = None
        self._business_type = None
        self._model_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.file_name = file_name
        if enable is not None:
            self.enable = enable
        self.remark = remark
        if version is not None:
            self.version = version
        self.library_type = library_type
        self.business_type = business_type
        self.model_type = model_type

    @property
    def id(self):
        """Gets the id of this QueryTemplateListOutput.  # noqa: E501

        模板文件ID template file Id  # noqa: E501

        :return: The id of this QueryTemplateListOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QueryTemplateListOutput.

        模板文件ID template file Id  # noqa: E501

        :param id: The id of this QueryTemplateListOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def file_name(self):
        """Gets the file_name of this QueryTemplateListOutput.  # noqa: E501

        模板文件名称 template file name  # noqa: E501

        :return: The file_name of this QueryTemplateListOutput.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this QueryTemplateListOutput.

        模板文件名称 template file name  # noqa: E501

        :param file_name: The file_name of this QueryTemplateListOutput.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def enable(self):
        """Gets the enable of this QueryTemplateListOutput.  # noqa: E501

        是否可用于创建模板方案 if it can be used to create template scenario  # noqa: E501

        :return: The enable of this QueryTemplateListOutput.  # noqa: E501
        :rtype: bool
        """
        return self._enable

    @enable.setter
    def enable(self, enable):
        """Sets the enable of this QueryTemplateListOutput.

        是否可用于创建模板方案 if it can be used to create template scenario  # noqa: E501

        :param enable: The enable of this QueryTemplateListOutput.  # noqa: E501
        :type: bool
        """

        self._enable = enable

    @property
    def remark(self):
        """Gets the remark of this QueryTemplateListOutput.  # noqa: E501

        模板文件备注 template file remark  # noqa: E501

        :return: The remark of this QueryTemplateListOutput.  # noqa: E501
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """Sets the remark of this QueryTemplateListOutput.

        模板文件备注 template file remark  # noqa: E501

        :param remark: The remark of this QueryTemplateListOutput.  # noqa: E501
        :type: str
        """

        self._remark = remark

    @property
    def version(self):
        """Gets the version of this QueryTemplateListOutput.  # noqa: E501

        模板文件版本 template file version  # noqa: E501

        :return: The version of this QueryTemplateListOutput.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this QueryTemplateListOutput.

        模板文件版本 template file version  # noqa: E501

        :param version: The version of this QueryTemplateListOutput.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def library_type(self):
        """Gets the library_type of this QueryTemplateListOutput.  # noqa: E501

        库类型  # noqa: E501

        :return: The library_type of this QueryTemplateListOutput.  # noqa: E501
        :rtype: str
        """
        return self._library_type

    @library_type.setter
    def library_type(self, library_type):
        """Sets the library_type of this QueryTemplateListOutput.

        库类型  # noqa: E501

        :param library_type: The library_type of this QueryTemplateListOutput.  # noqa: E501
        :type: str
        """

        self._library_type = library_type

    @property
    def business_type(self):
        """Gets the business_type of this QueryTemplateListOutput.  # noqa: E501

        业务类型  # noqa: E501

        :return: The business_type of this QueryTemplateListOutput.  # noqa: E501
        :rtype: str
        """
        return self._business_type

    @business_type.setter
    def business_type(self, business_type):
        """Sets the business_type of this QueryTemplateListOutput.

        业务类型  # noqa: E501

        :param business_type: The business_type of this QueryTemplateListOutput.  # noqa: E501
        :type: str
        """

        self._business_type = business_type

    @property
    def model_type(self):
        """Gets the model_type of this QueryTemplateListOutput.  # noqa: E501

        模型类型  # noqa: E501

        :return: The model_type of this QueryTemplateListOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this QueryTemplateListOutput.

        模型类型  # noqa: E501

        :param model_type: The model_type of this QueryTemplateListOutput.  # noqa: E501
        :type: str
        """

        self._model_type = model_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryTemplateListOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryTemplateListOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class DeviceInfosInputWithAttr(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key_words': 'str',
        'page_index': 'int',
        'page_size': 'int',
        'sort_property': 'int',
        'sort_order': 'int',
        'type': 'str',
        'attributes': 'list[AttributesParamItem]'
    }

    attribute_map = {
        'key_words': 'keyWords',
        'page_index': 'pageIndex',
        'page_size': 'pageSize',
        'sort_property': 'sortProperty',
        'sort_order': 'sortOrder',
        'type': 'type',
        'attributes': 'attributes'
    }

    def __init__(self, key_words=None, page_index=None, page_size=None, sort_property=None, sort_order=None, type=None, attributes=None, local_vars_configuration=None):  # noqa: E501
        """DeviceInfosInputWithAttr - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key_words = None
        self._page_index = None
        self._page_size = None
        self._sort_property = None
        self._sort_order = None
        self._type = None
        self._attributes = None
        self.discriminator = None

        self.key_words = key_words
        if page_index is not None:
            self.page_index = page_index
        if page_size is not None:
            self.page_size = page_size
        self.sort_property = sort_property
        self.sort_order = sort_order
        self.type = type
        self.attributes = attributes

    @property
    def key_words(self):
        """Gets the key_words of this DeviceInfosInputWithAttr.  # noqa: E501


        :return: The key_words of this DeviceInfosInputWithAttr.  # noqa: E501
        :rtype: str
        """
        return self._key_words

    @key_words.setter
    def key_words(self, key_words):
        """Sets the key_words of this DeviceInfosInputWithAttr.


        :param key_words: The key_words of this DeviceInfosInputWithAttr.  # noqa: E501
        :type: str
        """

        self._key_words = key_words

    @property
    def page_index(self):
        """Gets the page_index of this DeviceInfosInputWithAttr.  # noqa: E501


        :return: The page_index of this DeviceInfosInputWithAttr.  # noqa: E501
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """Sets the page_index of this DeviceInfosInputWithAttr.


        :param page_index: The page_index of this DeviceInfosInputWithAttr.  # noqa: E501
        :type: int
        """

        self._page_index = page_index

    @property
    def page_size(self):
        """Gets the page_size of this DeviceInfosInputWithAttr.  # noqa: E501


        :return: The page_size of this DeviceInfosInputWithAttr.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DeviceInfosInputWithAttr.


        :param page_size: The page_size of this DeviceInfosInputWithAttr.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def sort_property(self):
        """Gets the sort_property of this DeviceInfosInputWithAttr.  # noqa: E501

        用于排序的属性 sort attribute:  0-createdTime,  1-label,  2-name,  # noqa: E501

        :return: The sort_property of this DeviceInfosInputWithAttr.  # noqa: E501
        :rtype: int
        """
        return self._sort_property

    @sort_property.setter
    def sort_property(self, sort_property):
        """Sets the sort_property of this DeviceInfosInputWithAttr.

        用于排序的属性 sort attribute:  0-createdTime,  1-label,  2-name,  # noqa: E501

        :param sort_property: The sort_property of this DeviceInfosInputWithAttr.  # noqa: E501
        :type: int
        """
        allowed_values = [None,0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and sort_property not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `sort_property` ({0}), must be one of {1}"  # noqa: E501
                .format(sort_property, allowed_values)
            )

        self._sort_property = sort_property

    @property
    def sort_order(self):
        """Gets the sort_order of this DeviceInfosInputWithAttr.  # noqa: E501

        排序的方式 sort order:  0-ASC,  1-DESC  # noqa: E501

        :return: The sort_order of this DeviceInfosInputWithAttr.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this DeviceInfosInputWithAttr.

        排序的方式 sort order:  0-ASC,  1-DESC  # noqa: E501

        :param sort_order: The sort_order of this DeviceInfosInputWithAttr.  # noqa: E501
        :type: int
        """
        allowed_values = [None,0, 1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and sort_order not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `sort_order` ({0}), must be one of {1}"  # noqa: E501
                .format(sort_order, allowed_values)
            )

        self._sort_order = sort_order

    @property
    def type(self):
        """Gets the type of this DeviceInfosInputWithAttr.  # noqa: E501

        设备类型  # noqa: E501

        :return: The type of this DeviceInfosInputWithAttr.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DeviceInfosInputWithAttr.

        设备类型  # noqa: E501

        :param type: The type of this DeviceInfosInputWithAttr.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def attributes(self):
        """Gets the attributes of this DeviceInfosInputWithAttr.  # noqa: E501


        :return: The attributes of this DeviceInfosInputWithAttr.  # noqa: E501
        :rtype: list[AttributesParamItem]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this DeviceInfosInputWithAttr.


        :param attributes: The attributes of this DeviceInfosInputWithAttr.  # noqa: E501
        :type: list[AttributesParamItem]
        """

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceInfosInputWithAttr):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceInfosInputWithAttr):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class SelectItemNode(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'node_type': 'int',
        'code': 'str',
        'name': 'str',
        'detailed_info': 'SelectItemNodeDetailInfo',
        'child_nodes': 'list[SelectItemNode]'
    }

    attribute_map = {
        'node_type': 'nodeType',
        'code': 'code',
        'name': 'name',
        'detailed_info': 'detailedInfo',
        'child_nodes': 'childNodes'
    }

    def __init__(self, node_type=None, code=None, name=None, detailed_info=None, child_nodes=None, local_vars_configuration=None):  # noqa: E501
        """SelectItemNode - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._node_type = None
        self._code = None
        self._name = None
        self._detailed_info = None
        self._child_nodes = None
        self.discriminator = None

        if node_type is not None:
            self.node_type = node_type
        self.code = code
        self.name = name
        if detailed_info is not None:
            self.detailed_info = detailed_info
        self.child_nodes = child_nodes

    @property
    def node_type(self):
        """Gets the node_type of this SelectItemNode.  # noqa: E501

        选择节点的类型 select node type  # noqa: E501

        :return: The node_type of this SelectItemNode.  # noqa: E501
        :rtype: int
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """Sets the node_type of this SelectItemNode.

        选择节点的类型 select node type  # noqa: E501

        :param node_type: The node_type of this SelectItemNode.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, 4, 5, 6]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and node_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `node_type` ({0}), must be one of {1}"  # noqa: E501
                .format(node_type, allowed_values)
            )

        self._node_type = node_type

    @property
    def code(self):
        """Gets the code of this SelectItemNode.  # noqa: E501

        代码 code  # noqa: E501

        :return: The code of this SelectItemNode.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this SelectItemNode.

        代码 code  # noqa: E501

        :param code: The code of this SelectItemNode.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def name(self):
        """Gets the name of this SelectItemNode.  # noqa: E501

        名称，用于显示 name for display  # noqa: E501

        :return: The name of this SelectItemNode.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SelectItemNode.

        名称，用于显示 name for display  # noqa: E501

        :param name: The name of this SelectItemNode.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def detailed_info(self):
        """Gets the detailed_info of this SelectItemNode.  # noqa: E501


        :return: The detailed_info of this SelectItemNode.  # noqa: E501
        :rtype: SelectItemNodeDetailInfo
        """
        return self._detailed_info

    @detailed_info.setter
    def detailed_info(self, detailed_info):
        """Sets the detailed_info of this SelectItemNode.


        :param detailed_info: The detailed_info of this SelectItemNode.  # noqa: E501
        :type: SelectItemNodeDetailInfo
        """

        self._detailed_info = detailed_info

    @property
    def child_nodes(self):
        """Gets the child_nodes of this SelectItemNode.  # noqa: E501

        子节点列表 sub node list  # noqa: E501

        :return: The child_nodes of this SelectItemNode.  # noqa: E501
        :rtype: list[SelectItemNode]
        """
        return self._child_nodes

    @child_nodes.setter
    def child_nodes(self, child_nodes):
        """Sets the child_nodes of this SelectItemNode.

        子节点列表 sub node list  # noqa: E501

        :param child_nodes: The child_nodes of this SelectItemNode.  # noqa: E501
        :type: list[SelectItemNode]
        """

        self._child_nodes = child_nodes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SelectItemNode):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SelectItemNode):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-configuration-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_model_configuration_service.api_client import ApiClient
from dhicn_model_configuration_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class LegendApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_model_configuration_legend_all_legend_get(self, **kwargs):  # noqa: E501
        """获取所有的图例项 Get all legend items  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_all_legend_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[LegendItemDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_configuration_legend_all_legend_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_configuration_legend_all_legend_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有的图例项 Get all legend items  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_all_legend_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[LegendItemDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_configuration_legend_all_legend_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-configuration/legend/all-legend', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LegendItemDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_configuration_legend_classify_legend_get(self, **kwargs):  # noqa: E501
        """获取某个图例项的等级设置信息 Get legend classifications  # noqa: E501

        根据模型类型和数据类型，获取对应的图例项的等级设置信息，包括等级范围、颜色、描述等信息 Get the legend classifications, including information like classification data range, color, description, etc. by model type and data type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_classify_legend_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str model_type: 图例项对应的模型类型 model type of the legend item
        :param str data_type: 图例项对应的数据类型 data type of the legend item
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ClassifyLegendInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_configuration_legend_classify_legend_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_configuration_legend_classify_legend_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取某个图例项的等级设置信息 Get legend classifications  # noqa: E501

        根据模型类型和数据类型，获取对应的图例项的等级设置信息，包括等级范围、颜色、描述等信息 Get the legend classifications, including information like classification data range, color, description, etc. by model type and data type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_classify_legend_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str model_type: 图例项对应的模型类型 model type of the legend item
        :param str data_type: 图例项对应的数据类型 data type of the legend item
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ClassifyLegendInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_type',
            'data_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_configuration_legend_classify_legend_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'model_type' in local_var_params and local_var_params['model_type'] is not None:  # noqa: E501
            query_params.append(('modelType', local_var_params['model_type']))  # noqa: E501
        if 'data_type' in local_var_params and local_var_params['data_type'] is not None:  # noqa: E501
            query_params.append(('dataType', local_var_params['data_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-configuration/legend/classify-legend', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ClassifyLegendInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_configuration_legend_legend_item_get(self, **kwargs):  # noqa: E501
        """根据模型类型和数据类型获取对应的图例项 Get legend item by model type and data type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_legend_item_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str model_type: 图例项对应的模型类型 model type of the legend item
        :param str data_type: 图例项对应的数据类型 data type of the legend item
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: LegendItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_configuration_legend_legend_item_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_configuration_legend_legend_item_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据模型类型和数据类型获取对应的图例项 Get legend item by model type and data type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_legend_item_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str model_type: 图例项对应的模型类型 model type of the legend item
        :param str data_type: 图例项对应的数据类型 data type of the legend item
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(LegendItemDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_type',
            'data_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_configuration_legend_legend_item_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'model_type' in local_var_params and local_var_params['model_type'] is not None:  # noqa: E501
            query_params.append(('modelType', local_var_params['model_type']))  # noqa: E501
        if 'data_type' in local_var_params and local_var_params['data_type'] is not None:  # noqa: E501
            query_params.append(('dataType', local_var_params['data_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-configuration/legend/legend-item', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LegendItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_configuration_legend_save_classify_post(self, **kwargs):  # noqa: E501
        """保存图例项对应的等级设置信息 Save legend classifications  # noqa: E501

        根据模型类型和数据类型，添加或更新图例项对应的等级设置信息 Save or update legend classifications by model type and data type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_save_classify_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ClassifyLegendInput classify_legend_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_configuration_legend_save_classify_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_configuration_legend_save_classify_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存图例项对应的等级设置信息 Save legend classifications  # noqa: E501

        根据模型类型和数据类型，添加或更新图例项对应的等级设置信息 Save or update legend classifications by model type and data type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_save_classify_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ClassifyLegendInput classify_legend_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'classify_legend_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_configuration_legend_save_classify_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'classify_legend_input' in local_var_params:
            body_params = local_var_params['classify_legend_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-configuration/legend/save-classify', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_configuration_legend_save_legend_type_post(self, **kwargs):  # noqa: E501
        """保存图例项信息 Save legend items  # noqa: E501

        添加或者更新图例项信息，在输入参数中，modelType可以是River, Network, M2D等代表模型类型的值，resultType可以是结果文件（res1d，dfsu等）中的数据项 Add or update legend items. Among the augments, modelType can be River, Network, M2D, etc., and resultType is data items in the result files (res1d, dfsu, etc.).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_save_legend_type_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[LegendItemDto] legend_item_dto:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_configuration_legend_save_legend_type_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_configuration_legend_save_legend_type_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存图例项信息 Save legend items  # noqa: E501

        添加或者更新图例项信息，在输入参数中，modelType可以是River, Network, M2D等代表模型类型的值，resultType可以是结果文件（res1d，dfsu等）中的数据项 Add or update legend items. Among the augments, modelType can be River, Network, M2D, etc., and resultType is data items in the result files (res1d, dfsu, etc.).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_configuration_legend_save_legend_type_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[LegendItemDto] legend_item_dto:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'legend_item_dto'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_configuration_legend_save_legend_type_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'legend_item_dto' in local_var_params:
            body_params = local_var_params['legend_item_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-configuration/legend/save-legend-type', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class QueryValveDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'muid': 'str',
        'setting': 'float',
        'setting_no': 'WdValveSettingNo',
        'valve_type': 'WdValveTypeNo',
        'valve_status': 'WdValveStatusNo',
        'geom_wkt': 'str',
        'to_y': 'float',
        'to_x': 'float',
        'from_y': 'float',
        'from_x': 'float',
        'coor_str': 'str',
        'street_name': 'str',
        'description': 'str',
        'note': 'str',
        'data_source': 'str',
        'zone_id': 'str',
        'loss_coeff': 'float',
        'diameter': 'float',
        'to_node': 'str',
        'from_node': 'str',
        'oper_curve_id': 'str',
        'valve_curve_id': 'str',
        'create_time': 'datetime',
        'id': 'str'
    }

    attribute_map = {
        'muid': 'muid',
        'setting': 'setting',
        'setting_no': 'settingNo',
        'valve_type': 'valveType',
        'valve_status': 'valveStatus',
        'geom_wkt': 'geomWKT',
        'to_y': 'toY',
        'to_x': 'toX',
        'from_y': 'fromY',
        'from_x': 'fromX',
        'coor_str': 'coorStr',
        'street_name': 'streetName',
        'description': 'description',
        'note': 'note',
        'data_source': 'dataSource',
        'zone_id': 'zoneID',
        'loss_coeff': 'lossCoeff',
        'diameter': 'diameter',
        'to_node': 'toNode',
        'from_node': 'fromNode',
        'oper_curve_id': 'operCurveID',
        'valve_curve_id': 'valveCurveID',
        'create_time': 'createTime',
        'id': 'id'
    }

    def __init__(self, muid=None, setting=None, setting_no=None, valve_type=None, valve_status=None, geom_wkt=None, to_y=None, to_x=None, from_y=None, from_x=None, coor_str=None, street_name=None, description=None, note=None, data_source=None, zone_id=None, loss_coeff=None, diameter=None, to_node=None, from_node=None, oper_curve_id=None, valve_curve_id=None, create_time=None, id=None, local_vars_configuration=None):  # noqa: E501
        """QueryValveDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._muid = None
        self._setting = None
        self._setting_no = None
        self._valve_type = None
        self._valve_status = None
        self._geom_wkt = None
        self._to_y = None
        self._to_x = None
        self._from_y = None
        self._from_x = None
        self._coor_str = None
        self._street_name = None
        self._description = None
        self._note = None
        self._data_source = None
        self._zone_id = None
        self._loss_coeff = None
        self._diameter = None
        self._to_node = None
        self._from_node = None
        self._oper_curve_id = None
        self._valve_curve_id = None
        self._create_time = None
        self._id = None
        self.discriminator = None

        self.muid = muid
        if setting is not None:
            self.setting = setting
        if setting_no is not None:
            self.setting_no = setting_no
        if valve_type is not None:
            self.valve_type = valve_type
        if valve_status is not None:
            self.valve_status = valve_status
        self.geom_wkt = geom_wkt
        if to_y is not None:
            self.to_y = to_y
        if to_x is not None:
            self.to_x = to_x
        if from_y is not None:
            self.from_y = from_y
        if from_x is not None:
            self.from_x = from_x
        self.coor_str = coor_str
        self.street_name = street_name
        self.description = description
        self.note = note
        self.data_source = data_source
        self.zone_id = zone_id
        if loss_coeff is not None:
            self.loss_coeff = loss_coeff
        if diameter is not None:
            self.diameter = diameter
        self.to_node = to_node
        self.from_node = from_node
        self.oper_curve_id = oper_curve_id
        self.valve_curve_id = valve_curve_id
        if create_time is not None:
            self.create_time = create_time
        if id is not None:
            self.id = id

    @property
    def muid(self):
        """Gets the muid of this QueryValveDto.  # noqa: E501

        模型中阀门的ID valve muid  # noqa: E501

        :return: The muid of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._muid

    @muid.setter
    def muid(self, muid):
        """Sets the muid of this QueryValveDto.

        模型中阀门的ID valve muid  # noqa: E501

        :param muid: The muid of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._muid = muid

    @property
    def setting(self):
        """Gets the setting of this QueryValveDto.  # noqa: E501

        设置的数值 setting valve  # noqa: E501

        :return: The setting of this QueryValveDto.  # noqa: E501
        :rtype: float
        """
        return self._setting

    @setting.setter
    def setting(self, setting):
        """Sets the setting of this QueryValveDto.

        设置的数值 setting valve  # noqa: E501

        :param setting: The setting of this QueryValveDto.  # noqa: E501
        :type: float
        """

        self._setting = setting

    @property
    def setting_no(self):
        """Gets the setting_no of this QueryValveDto.  # noqa: E501


        :return: The setting_no of this QueryValveDto.  # noqa: E501
        :rtype: WdValveSettingNo
        """
        return self._setting_no

    @setting_no.setter
    def setting_no(self, setting_no):
        """Sets the setting_no of this QueryValveDto.


        :param setting_no: The setting_no of this QueryValveDto.  # noqa: E501
        :type: WdValveSettingNo
        """

        self._setting_no = setting_no

    @property
    def valve_type(self):
        """Gets the valve_type of this QueryValveDto.  # noqa: E501


        :return: The valve_type of this QueryValveDto.  # noqa: E501
        :rtype: WdValveTypeNo
        """
        return self._valve_type

    @valve_type.setter
    def valve_type(self, valve_type):
        """Sets the valve_type of this QueryValveDto.


        :param valve_type: The valve_type of this QueryValveDto.  # noqa: E501
        :type: WdValveTypeNo
        """

        self._valve_type = valve_type

    @property
    def valve_status(self):
        """Gets the valve_status of this QueryValveDto.  # noqa: E501


        :return: The valve_status of this QueryValveDto.  # noqa: E501
        :rtype: WdValveStatusNo
        """
        return self._valve_status

    @valve_status.setter
    def valve_status(self, valve_status):
        """Sets the valve_status of this QueryValveDto.


        :param valve_status: The valve_status of this QueryValveDto.  # noqa: E501
        :type: WdValveStatusNo
        """

        self._valve_status = valve_status

    @property
    def geom_wkt(self):
        """Gets the geom_wkt of this QueryValveDto.  # noqa: E501

        阀门空间信息 valve geometry in wkt format  # noqa: E501

        :return: The geom_wkt of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._geom_wkt

    @geom_wkt.setter
    def geom_wkt(self, geom_wkt):
        """Sets the geom_wkt of this QueryValveDto.

        阀门空间信息 valve geometry in wkt format  # noqa: E501

        :param geom_wkt: The geom_wkt of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._geom_wkt = geom_wkt

    @property
    def to_y(self):
        """Gets the to_y of this QueryValveDto.  # noqa: E501

        终止节点坐标值Y coordinate y of to-node  # noqa: E501

        :return: The to_y of this QueryValveDto.  # noqa: E501
        :rtype: float
        """
        return self._to_y

    @to_y.setter
    def to_y(self, to_y):
        """Sets the to_y of this QueryValveDto.

        终止节点坐标值Y coordinate y of to-node  # noqa: E501

        :param to_y: The to_y of this QueryValveDto.  # noqa: E501
        :type: float
        """

        self._to_y = to_y

    @property
    def to_x(self):
        """Gets the to_x of this QueryValveDto.  # noqa: E501

        终止节点坐标值X coordinate x of to-node  # noqa: E501

        :return: The to_x of this QueryValveDto.  # noqa: E501
        :rtype: float
        """
        return self._to_x

    @to_x.setter
    def to_x(self, to_x):
        """Sets the to_x of this QueryValveDto.

        终止节点坐标值X coordinate x of to-node  # noqa: E501

        :param to_x: The to_x of this QueryValveDto.  # noqa: E501
        :type: float
        """

        self._to_x = to_x

    @property
    def from_y(self):
        """Gets the from_y of this QueryValveDto.  # noqa: E501

        起始节点坐标值Y coordinate y of from-node  # noqa: E501

        :return: The from_y of this QueryValveDto.  # noqa: E501
        :rtype: float
        """
        return self._from_y

    @from_y.setter
    def from_y(self, from_y):
        """Sets the from_y of this QueryValveDto.

        起始节点坐标值Y coordinate y of from-node  # noqa: E501

        :param from_y: The from_y of this QueryValveDto.  # noqa: E501
        :type: float
        """

        self._from_y = from_y

    @property
    def from_x(self):
        """Gets the from_x of this QueryValveDto.  # noqa: E501

        起始节点坐标值X coordinate x of from-node  # noqa: E501

        :return: The from_x of this QueryValveDto.  # noqa: E501
        :rtype: float
        """
        return self._from_x

    @from_x.setter
    def from_x(self, from_x):
        """Sets the from_x of this QueryValveDto.

        起始节点坐标值X coordinate x of from-node  # noqa: E501

        :param from_x: The from_x of this QueryValveDto.  # noqa: E501
        :type: float
        """

        self._from_x = from_x

    @property
    def coor_str(self):
        """Gets the coor_str of this QueryValveDto.  # noqa: E501

        坐标信息 coordinate  # noqa: E501

        :return: The coor_str of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._coor_str

    @coor_str.setter
    def coor_str(self, coor_str):
        """Sets the coor_str of this QueryValveDto.

        坐标信息 coordinate  # noqa: E501

        :param coor_str: The coor_str of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._coor_str = coor_str

    @property
    def street_name(self):
        """Gets the street_name of this QueryValveDto.  # noqa: E501

        街道名称 street name  # noqa: E501

        :return: The street_name of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this QueryValveDto.

        街道名称 street name  # noqa: E501

        :param street_name: The street_name of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._street_name = street_name

    @property
    def description(self):
        """Gets the description of this QueryValveDto.  # noqa: E501

        描述 description  # noqa: E501

        :return: The description of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this QueryValveDto.

        描述 description  # noqa: E501

        :param description: The description of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def note(self):
        """Gets the note of this QueryValveDto.  # noqa: E501

        备注 note  # noqa: E501

        :return: The note of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this QueryValveDto.

        备注 note  # noqa: E501

        :param note: The note of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._note = note

    @property
    def data_source(self):
        """Gets the data_source of this QueryValveDto.  # noqa: E501

        数据源 data source  # noqa: E501

        :return: The data_source of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """Sets the data_source of this QueryValveDto.

        数据源 data source  # noqa: E501

        :param data_source: The data_source of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._data_source = data_source

    @property
    def zone_id(self):
        """Gets the zone_id of this QueryValveDto.  # noqa: E501

        分区ID zone id  # noqa: E501

        :return: The zone_id of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this QueryValveDto.

        分区ID zone id  # noqa: E501

        :param zone_id: The zone_id of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    @property
    def loss_coeff(self):
        """Gets the loss_coeff of this QueryValveDto.  # noqa: E501

        损失系数 loss coefficient  # noqa: E501

        :return: The loss_coeff of this QueryValveDto.  # noqa: E501
        :rtype: float
        """
        return self._loss_coeff

    @loss_coeff.setter
    def loss_coeff(self, loss_coeff):
        """Sets the loss_coeff of this QueryValveDto.

        损失系数 loss coefficient  # noqa: E501

        :param loss_coeff: The loss_coeff of this QueryValveDto.  # noqa: E501
        :type: float
        """

        self._loss_coeff = loss_coeff

    @property
    def diameter(self):
        """Gets the diameter of this QueryValveDto.  # noqa: E501

        直径 diameter  # noqa: E501

        :return: The diameter of this QueryValveDto.  # noqa: E501
        :rtype: float
        """
        return self._diameter

    @diameter.setter
    def diameter(self, diameter):
        """Sets the diameter of this QueryValveDto.

        直径 diameter  # noqa: E501

        :param diameter: The diameter of this QueryValveDto.  # noqa: E501
        :type: float
        """

        self._diameter = diameter

    @property
    def to_node(self):
        """Gets the to_node of this QueryValveDto.  # noqa: E501

        终止节点 to node  # noqa: E501

        :return: The to_node of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._to_node

    @to_node.setter
    def to_node(self, to_node):
        """Sets the to_node of this QueryValveDto.

        终止节点 to node  # noqa: E501

        :param to_node: The to_node of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._to_node = to_node

    @property
    def from_node(self):
        """Gets the from_node of this QueryValveDto.  # noqa: E501

        起始节点 from node  # noqa: E501

        :return: The from_node of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._from_node

    @from_node.setter
    def from_node(self, from_node):
        """Sets the from_node of this QueryValveDto.

        起始节点 from node  # noqa: E501

        :param from_node: The from_node of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._from_node = from_node

    @property
    def oper_curve_id(self):
        """Gets the oper_curve_id of this QueryValveDto.  # noqa: E501

        调度曲线ID operation schedule curve id  # noqa: E501

        :return: The oper_curve_id of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._oper_curve_id

    @oper_curve_id.setter
    def oper_curve_id(self, oper_curve_id):
        """Sets the oper_curve_id of this QueryValveDto.

        调度曲线ID operation schedule curve id  # noqa: E501

        :param oper_curve_id: The oper_curve_id of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._oper_curve_id = oper_curve_id

    @property
    def valve_curve_id(self):
        """Gets the valve_curve_id of this QueryValveDto.  # noqa: E501

        阀门曲线ID valve characteristic curve id  # noqa: E501

        :return: The valve_curve_id of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._valve_curve_id

    @valve_curve_id.setter
    def valve_curve_id(self, valve_curve_id):
        """Sets the valve_curve_id of this QueryValveDto.

        阀门曲线ID valve characteristic curve id  # noqa: E501

        :param valve_curve_id: The valve_curve_id of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._valve_curve_id = valve_curve_id

    @property
    def create_time(self):
        """Gets the create_time of this QueryValveDto.  # noqa: E501

        创建时间 create time  # noqa: E501

        :return: The create_time of this QueryValveDto.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this QueryValveDto.

        创建时间 create time  # noqa: E501

        :param create_time: The create_time of this QueryValveDto.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def id(self):
        """Gets the id of this QueryValveDto.  # noqa: E501

        阀门ID valve id  # noqa: E501

        :return: The id of this QueryValveDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QueryValveDto.

        阀门ID valve id  # noqa: E501

        :param id: The id of this QueryValveDto.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryValveDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryValveDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class HistoryScheduleSuggestionRecordDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'creation_time': 'datetime',
        'tenant_id': 'str',
        'last_modification_time': 'datetime',
        'indicator': 'str',
        'show_name': 'str',
        'date_type': 'str',
        'measure_value': 'float',
        'simulation_value': 'float',
        'suggestion': 'str',
        'operation': 'str',
        'time': 'datetime',
        'is_apply': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'creation_time': 'creationTime',
        'tenant_id': 'tenantId',
        'last_modification_time': 'lastModificationTime',
        'indicator': 'indicator',
        'show_name': 'showName',
        'date_type': 'dateType',
        'measure_value': 'measureValue',
        'simulation_value': 'simulationValue',
        'suggestion': 'suggestion',
        'operation': 'operation',
        'time': 'time',
        'is_apply': 'isApply'
    }

    def __init__(self, id=None, creation_time=None, tenant_id=None, last_modification_time=None, indicator=None, show_name=None, date_type=None, measure_value=None, simulation_value=None, suggestion=None, operation=None, time=None, is_apply=None, local_vars_configuration=None):  # noqa: E501
        """HistoryScheduleSuggestionRecordDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._creation_time = None
        self._tenant_id = None
        self._last_modification_time = None
        self._indicator = None
        self._show_name = None
        self._date_type = None
        self._measure_value = None
        self._simulation_value = None
        self._suggestion = None
        self._operation = None
        self._time = None
        self._is_apply = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if creation_time is not None:
            self.creation_time = creation_time
        self.tenant_id = tenant_id
        self.last_modification_time = last_modification_time
        self.indicator = indicator
        self.show_name = show_name
        self.date_type = date_type
        if measure_value is not None:
            self.measure_value = measure_value
        if simulation_value is not None:
            self.simulation_value = simulation_value
        self.suggestion = suggestion
        self.operation = operation
        if time is not None:
            self.time = time
        if is_apply is not None:
            self.is_apply = is_apply

    @property
    def id(self):
        """Gets the id of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The id of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HistoryScheduleSuggestionRecordDto.


        :param id: The id of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def creation_time(self):
        """Gets the creation_time of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The creation_time of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this HistoryScheduleSuggestionRecordDto.


        :param creation_time: The creation_time of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def tenant_id(self):
        """Gets the tenant_id of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The tenant_id of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this HistoryScheduleSuggestionRecordDto.


        :param tenant_id: The tenant_id of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def last_modification_time(self):
        """Gets the last_modification_time of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The last_modification_time of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modification_time

    @last_modification_time.setter
    def last_modification_time(self, last_modification_time):
        """Sets the last_modification_time of this HistoryScheduleSuggestionRecordDto.


        :param last_modification_time: The last_modification_time of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: datetime
        """

        self._last_modification_time = last_modification_time

    @property
    def indicator(self):
        """Gets the indicator of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The indicator of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this HistoryScheduleSuggestionRecordDto.


        :param indicator: The indicator of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def show_name(self):
        """Gets the show_name of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The show_name of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: str
        """
        return self._show_name

    @show_name.setter
    def show_name(self, show_name):
        """Sets the show_name of this HistoryScheduleSuggestionRecordDto.


        :param show_name: The show_name of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: str
        """

        self._show_name = show_name

    @property
    def date_type(self):
        """Gets the date_type of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The date_type of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: str
        """
        return self._date_type

    @date_type.setter
    def date_type(self, date_type):
        """Sets the date_type of this HistoryScheduleSuggestionRecordDto.


        :param date_type: The date_type of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: str
        """

        self._date_type = date_type

    @property
    def measure_value(self):
        """Gets the measure_value of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The measure_value of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: float
        """
        return self._measure_value

    @measure_value.setter
    def measure_value(self, measure_value):
        """Sets the measure_value of this HistoryScheduleSuggestionRecordDto.


        :param measure_value: The measure_value of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: float
        """

        self._measure_value = measure_value

    @property
    def simulation_value(self):
        """Gets the simulation_value of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The simulation_value of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: float
        """
        return self._simulation_value

    @simulation_value.setter
    def simulation_value(self, simulation_value):
        """Sets the simulation_value of this HistoryScheduleSuggestionRecordDto.


        :param simulation_value: The simulation_value of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: float
        """

        self._simulation_value = simulation_value

    @property
    def suggestion(self):
        """Gets the suggestion of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The suggestion of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: str
        """
        return self._suggestion

    @suggestion.setter
    def suggestion(self, suggestion):
        """Sets the suggestion of this HistoryScheduleSuggestionRecordDto.


        :param suggestion: The suggestion of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: str
        """

        self._suggestion = suggestion

    @property
    def operation(self):
        """Gets the operation of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The operation of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this HistoryScheduleSuggestionRecordDto.


        :param operation: The operation of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: str
        """

        self._operation = operation

    @property
    def time(self):
        """Gets the time of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The time of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this HistoryScheduleSuggestionRecordDto.


        :param time: The time of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def is_apply(self):
        """Gets the is_apply of this HistoryScheduleSuggestionRecordDto.  # noqa: E501


        :return: The is_apply of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_apply

    @is_apply.setter
    def is_apply(self, is_apply):
        """Sets the is_apply of this HistoryScheduleSuggestionRecordDto.


        :param is_apply: The is_apply of this HistoryScheduleSuggestionRecordDto.  # noqa: E501
        :type: bool
        """

        self._is_apply = is_apply

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoryScheduleSuggestionRecordDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HistoryScheduleSuggestionRecordDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class WdIndicatorAttr(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'indicator': 'str',
        'min_clean': 'float',
        'max_clean': 'float',
        'accuracy_check': 'bool'
    }

    attribute_map = {
        'indicator': 'indicator',
        'min_clean': 'minClean',
        'max_clean': 'maxClean',
        'accuracy_check': 'accuracyCheck'
    }

    def __init__(self, indicator=None, min_clean=None, max_clean=None, accuracy_check=None, local_vars_configuration=None):  # noqa: E501
        """WdIndicatorAttr - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._indicator = None
        self._min_clean = None
        self._max_clean = None
        self._accuracy_check = None
        self.discriminator = None

        self.indicator = indicator
        if min_clean is not None:
            self.min_clean = min_clean
        if max_clean is not None:
            self.max_clean = max_clean
        if accuracy_check is not None:
            self.accuracy_check = accuracy_check

    @property
    def indicator(self):
        """Gets the indicator of this WdIndicatorAttr.  # noqa: E501

        指标  # noqa: E501

        :return: The indicator of this WdIndicatorAttr.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this WdIndicatorAttr.

        指标  # noqa: E501

        :param indicator: The indicator of this WdIndicatorAttr.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def min_clean(self):
        """Gets the min_clean of this WdIndicatorAttr.  # noqa: E501

        触发数据清洗的最小值  # noqa: E501

        :return: The min_clean of this WdIndicatorAttr.  # noqa: E501
        :rtype: float
        """
        return self._min_clean

    @min_clean.setter
    def min_clean(self, min_clean):
        """Sets the min_clean of this WdIndicatorAttr.

        触发数据清洗的最小值  # noqa: E501

        :param min_clean: The min_clean of this WdIndicatorAttr.  # noqa: E501
        :type: float
        """

        self._min_clean = min_clean

    @property
    def max_clean(self):
        """Gets the max_clean of this WdIndicatorAttr.  # noqa: E501

        触发数据清洗的最大值  # noqa: E501

        :return: The max_clean of this WdIndicatorAttr.  # noqa: E501
        :rtype: float
        """
        return self._max_clean

    @max_clean.setter
    def max_clean(self, max_clean):
        """Sets the max_clean of this WdIndicatorAttr.

        触发数据清洗的最大值  # noqa: E501

        :param max_clean: The max_clean of this WdIndicatorAttr.  # noqa: E501
        :type: float
        """

        self._max_clean = max_clean

    @property
    def accuracy_check(self):
        """Gets the accuracy_check of this WdIndicatorAttr.  # noqa: E501

        是否参与精度计算  # noqa: E501

        :return: The accuracy_check of this WdIndicatorAttr.  # noqa: E501
        :rtype: bool
        """
        return self._accuracy_check

    @accuracy_check.setter
    def accuracy_check(self, accuracy_check):
        """Sets the accuracy_check of this WdIndicatorAttr.

        是否参与精度计算  # noqa: E501

        :param accuracy_check: The accuracy_check of this WdIndicatorAttr.  # noqa: E501
        :type: bool
        """

        self._accuracy_check = accuracy_check

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WdIndicatorAttr):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WdIndicatorAttr):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class SystemSettingOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'scenario_id': 'str',
        'item_code': 'str',
        'item_name': 'str',
        'type': 'str',
        'value': 'float',
        'sort': 'int',
        'principle_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'scenario_id': 'scenarioId',
        'item_code': 'itemCode',
        'item_name': 'itemName',
        'type': 'type',
        'value': 'value',
        'sort': 'sort',
        'principle_id': 'principleId'
    }

    def __init__(self, id=None, scenario_id=None, item_code=None, item_name=None, type=None, value=None, sort=None, principle_id=None, local_vars_configuration=None):  # noqa: E501
        """SystemSettingOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._scenario_id = None
        self._item_code = None
        self._item_name = None
        self._type = None
        self._value = None
        self._sort = None
        self._principle_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.scenario_id = scenario_id
        self.item_code = item_code
        self.item_name = item_name
        self.type = type
        if value is not None:
            self.value = value
        if sort is not None:
            self.sort = sort
        if principle_id is not None:
            self.principle_id = principle_id

    @property
    def id(self):
        """Gets the id of this SystemSettingOutput.  # noqa: E501


        :return: The id of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SystemSettingOutput.


        :param id: The id of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def scenario_id(self):
        """Gets the scenario_id of this SystemSettingOutput.  # noqa: E501


        :return: The scenario_id of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this SystemSettingOutput.


        :param scenario_id: The scenario_id of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def item_code(self):
        """Gets the item_code of this SystemSettingOutput.  # noqa: E501

        信息项编码  # noqa: E501

        :return: The item_code of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._item_code

    @item_code.setter
    def item_code(self, item_code):
        """Sets the item_code of this SystemSettingOutput.

        信息项编码  # noqa: E501

        :param item_code: The item_code of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._item_code = item_code

    @property
    def item_name(self):
        """Gets the item_name of this SystemSettingOutput.  # noqa: E501

        信息项  # noqa: E501

        :return: The item_name of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._item_name

    @item_name.setter
    def item_name(self, item_name):
        """Sets the item_name of this SystemSettingOutput.

        信息项  # noqa: E501

        :param item_name: The item_name of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._item_name = item_name

    @property
    def type(self):
        """Gets the type of this SystemSettingOutput.  # noqa: E501

        配置的类型，Plan--预案、AutoRun--滚动预报方案  # noqa: E501

        :return: The type of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SystemSettingOutput.

        配置的类型，Plan--预案、AutoRun--滚动预报方案  # noqa: E501

        :param type: The type of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def value(self):
        """Gets the value of this SystemSettingOutput.  # noqa: E501

        配水原则值  # noqa: E501

        :return: The value of this SystemSettingOutput.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this SystemSettingOutput.

        配水原则值  # noqa: E501

        :param value: The value of this SystemSettingOutput.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def sort(self):
        """Gets the sort of this SystemSettingOutput.  # noqa: E501


        :return: The sort of this SystemSettingOutput.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this SystemSettingOutput.


        :param sort: The sort of this SystemSettingOutput.  # noqa: E501
        :type: int
        """

        self._sort = sort

    @property
    def principle_id(self):
        """Gets the principle_id of this SystemSettingOutput.  # noqa: E501

        原则ID，将配水算法设置与原则绑定  # noqa: E501

        :return: The principle_id of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._principle_id

    @principle_id.setter
    def principle_id(self, principle_id):
        """Sets the principle_id of this SystemSettingOutput.

        原则ID，将配水算法设置与原则绑定  # noqa: E501

        :param principle_id: The principle_id of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._principle_id = principle_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemSettingOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SystemSettingOutput):
            return True

        return self.to_dict() != other.to_dict()
